package com.chinaitop.depot.customer.controller;


import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import com.chinaitop.depot.customer.model.BusinessCustomerBadrecordExample;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.customer.model.BusinessCustomerBadrecord;
import com.chinaitop.depot.customer.service.BusinessCustomerBadrecordService;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 粮库业务管理-客户不良信息管理
* <p>Title: BusinessCustomerBadrecordController</p>
* <p>Description: </p>
* @author yaoyabin
* @date 2017年10月25日 下午5:31:38
 */
@RestController
@RequestMapping(value="/depot/business/customerBadrecord")
@Api(value= "BusinessCustomerBadrecordController", description = "客户黑名单管理")
public class BusinessCustomerBadrecordController {
	
	@Resource
	private BusinessCustomerBadrecordService customerBadrecordService;

	@RequestMapping(value="/getList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="获取客户不良信息", notes = "查询客户不良信息列表，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query")
	})
	public PageInfo<BusinessCustomerBadrecord> getList(Integer pageNum, Integer pageSize, BusinessCustomerBadrecord customerBadrecord) {
		PageHelper.startPage(pageNum, pageSize);
		List<BusinessCustomerBadrecord> list = customerBadrecordService.selectBadreocrdJoinBusinessCustomer(customerBadrecord);	
		PageInfo<BusinessCustomerBadrecord> pageInfo = new PageInfo<BusinessCustomerBadrecord>(list);
		return pageInfo;
	}

	@RequestMapping(value="/edit", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="根据id获取信息", notes = "根据id获取信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "customerBadrecord", value = "数据对象", paramType = "query")
	})
	public BusinessCustomerBadrecord edit(BusinessCustomerBadrecord customerBadrecord) {
	    BusinessCustomerBadrecord customerBadrecordVOReturn = new BusinessCustomerBadrecord();
		if (customerBadrecord.getId() != null) {
		    List<BusinessCustomerBadrecord> list = customerBadrecordService.selectBadreocrdJoinBusinessCustomerEdit(customerBadrecord);
		    if (list != null && list.size() > 0) {
		        customerBadrecordVOReturn = list.get(0);
		    }
		}
		return customerBadrecordVOReturn;
	}

	@RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="保存数据", notes = "保存")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "customerBadrecordJson", value = "客户不良信息json", paramType = "query")
	})
	public Map<String, Object> save(String customerBadrecordJson) throws JsonParseException, JsonMappingException, IOException {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		try {
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            BusinessCustomerBadrecord customerBadrecord = (BusinessCustomerBadrecord)mapper.readValue(customerBadrecordJson, BusinessCustomerBadrecord.class);
            if (customerBadrecord.getId() == null) {
            	customerBadrecordService.add(customerBadrecord);
            } else {
            	customerBadrecordService.update(customerBadrecord);
            }
            modelMap.put("status", "success");
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
		return modelMap;
	}
	
	/**
	 * 删除
	 * @param id 主键
	 * @return
	 * @throws JsonParseException
	 * @throws JsonMappingException
	 * @throws IOException
	 */
	@RequestMapping(value="/remove", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="根据id删除信息", notes = "根据id删除信息")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "主键id", paramType = "query")
	})
	public Map<String, Object> remove(Integer id) throws JsonParseException, JsonMappingException, IOException {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		if (id != null) {
			customerBadrecordService.remove(id);
		}
		modelMap.put("status", "success");
		return modelMap;
	}

	@RequestMapping(value="/getBlrjl", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询该库该客户是否存在不良记录", notes = "出入库调用：1表示有不良记录，0表示没有")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "customerName", value = "客户名称", paramType = "query"),
		@ApiImplicitParam(name = "unitid", value = "组织机构ID", paramType = "query")
	})
	public String getBlrjl(String customerName, Integer unitid) {
		String flag = "0";

		BusinessCustomerBadrecordExample example = new BusinessCustomerBadrecordExample();
		BusinessCustomerBadrecordExample.Criteria criteria = example.createCriteria();
		criteria.andNameEqualTo(customerName);
		criteria.andOrgIdEqualTo(unitid);
		List<BusinessCustomerBadrecord> list = customerBadrecordService.queryByExample(example);
		if (null != list && list.size() > 0) {
			flag = "1";
		}

		return flag;
	}

}
