package com.chinaitop.depot.customer.controller;


import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.customer.model.BusinessCustomer;
import com.chinaitop.depot.customer.model.BusinessCustomerExample;
import com.chinaitop.depot.customer.model.BusinessCustomerExample.Criteria;
import com.chinaitop.depot.customer.service.BusinessCustomerService;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 粮库业务管理-客户管理
* <p>Title: BusinessCustomerController</p>
* <p>Description: </p>
* @author yaoyabin
* @date 2017年10月25日 下午5:33:42
 */
@RestController
@RequestMapping(value= {"/depot/business/customer"})
@Api(value= "BusinessCustomerController", description = "客户档案管理")
public class BusinessCustomerController {
	
	@Resource
	private BusinessCustomerService customerService;
  
	
	/**
	 * 获取数据列表
     * @param pageNum 页码
     * @param pageSize 每页显示条数
	 * @return
	 */
	@RequestMapping(value="/getList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="获取数据列表信息", notes = "查询数据列表，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "orgId", value = "当前登录人组织id", paramType = "query")
	})
	public PageInfo<BusinessCustomer> getList(HttpServletRequest request, 
	        Integer pageNum, Integer pageSize, BusinessCustomer customer,Integer orgId) {
        
        List<BusinessCustomer> list = customerService.list(pageNum, pageSize, customer, orgId);
		PageInfo<BusinessCustomer> pageInfo = new PageInfo<BusinessCustomer>(list);
		return pageInfo;
	}
	
	/**
	 * 获取客户黑名单列表
     * @param pageNum 页码
     * @param pageSize 每页显示条数
	 * @return
	 */
    @RequestMapping(value="/getBlackList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value="获取客户黑名单列表", notes = "查询客户黑名单列表，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query")
	})
    public PageInfo<BusinessCustomer> getBlackList(Integer pageNum, Integer pageSize, BusinessCustomer customer) {
        BusinessCustomerExample example = new BusinessCustomerExample();
        Criteria createCriteria = example.createCriteria();
        // 黑名单用户.
        createCriteria.andIsInBlacklistEqualTo(1);
        // 客户名称.
        if (StringUtils.isNotBlank(customer.getName())) {
            createCriteria.andNameLike("%" + customer.getName() + "%");
        }
        // 客户类型.
        if (customer.getClassify() != null) {
            createCriteria.andClassifyEqualTo(customer.getClassify());
        }
		if (null != customer.getOrgId()) {
			createCriteria.andOrgIdEqualTo(customer.getOrgId());
		}
        example.setOrderByClause("id desc");
        PageHelper.startPage(pageNum, pageSize);
        List<BusinessCustomer> list = customerService.queryByExample(example);  
        PageInfo<BusinessCustomer> pageInfo = new PageInfo<BusinessCustomer>(list);
        return pageInfo;
    }

    /**
     * 加入黑名单.
     * @param id 主键
     * @return
     */
    @RequestMapping(value="/putInBlackList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
    @ApiOperation(value="加入黑名单", notes = "加入黑名单.")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "id", paramType = "query")
	})
    public Map<String, Object> putInBlackList(Integer id) {
        Map<String, Object> returnMap = customerService.putInBlackList(id);
        return returnMap;
    }
    
    /**
     * 移出黑名单.
     * @param id 主键
     * @return
     */
    @RequestMapping(value="/removeBlackList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
    @ApiOperation(value="移出黑名单", notes = "移出黑名单.")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "id", paramType = "query")
	})
    public Map<String, Object> removeBlackList(Integer id) {
        Map<String, Object> returnMap = customerService.removeBlackList(id);
        return returnMap;
    }
    
	/**
	 * 根据id查找
	 * @param id 主键
	 * @return
	 */
	@RequestMapping(value="/edit", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="根据id查找", notes = "根据id查找")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "id", paramType = "query")
	})
	public BusinessCustomer edit(Integer id) {
		BusinessCustomer customer = new BusinessCustomer();
		if (id != null) {
			customer = customerService.findById(id);
		}
		return customer;
	}

	/**
	 * 保存
	 * @param customerJson 业务数据json
	 * @return
	 * @throws JsonParseException
	 * @throws JsonMappingException
	 * @throws IOException
	 */
	@RequestMapping(value="/save", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="保存数据", notes = "保存")
	public Map<String, Object> save(String customerJson,Integer orgId) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
		try {
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            BusinessCustomer customer = (BusinessCustomer)mapper.readValue(customerJson, BusinessCustomer.class);
            if (customer.getId() == null) {
            	customerService.add(customer, orgId);
            } else {
            	customerService.update(customer);
            }
            modelMap.put("status", "success");
            modelMap.put("id", customer.getId());
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        }
		return modelMap;
	}
	
	/**
	 * 删除
	 * @param id 主键
	 * @return
	 * @throws JsonParseException
	 * @throws JsonMappingException
	 * @throws IOException
	 */
	@RequestMapping(value="/remove", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="删除", notes = "根据id删除")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "id", paramType = "query")
	})
	public Map<String, Object> remove(Integer id,Integer orgId) throws JsonParseException, JsonMappingException, IOException {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		if (id != null) {
			customerService.remove(id,orgId);
		}
		modelMap.put("status", "success");
		return modelMap;
	}

	@RequestMapping(value="/checkRepeat", method = RequestMethod.GET)
	@ApiOperation(value="客户档案管理客户统一社会信用代码或身份证号重复校验", notes = "")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "orgId", value = "组织机构编码", paramType = "query"),
		@ApiImplicitParam(name = "zjh", value = "统一社会信用代码或身份证号", paramType = "query"),
		@ApiImplicitParam(name = "customerId", value = "客户ID", paramType = "query"),
		@ApiImplicitParam(name = "customerType", value = "客户类型(3152:个人客户,3153:企业客户)", paramType = "query"),
		@ApiImplicitParam(name = "customerName", value = "客户名称", paramType = "query")
	})
	public String checkRepeat(Integer orgId, String zjh, Integer customerId, Integer customerType, String customerName) {
		String flag = "false";
		try {
			flag = customerService.checkRepeat(orgId, zjh, customerId, customerType, customerName);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return flag;
	}

	@RequestMapping(value="/queryCustomerObj", method = RequestMethod.GET)
	@ApiOperation(value="查询一个客户档案信息的ID", notes = "")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "orgId", value = "组织机构编码", dataType="int", paramType = "query"),
		@ApiImplicitParam(name = "customerType", value = "客户类型(3152:个人客户,3153:企业客户)", dataType="int", paramType = "query"),
		@ApiImplicitParam(name = "customerName", value = "客户名称", dataType="String", paramType = "query")
	})
	public Integer queryCustomerObj(Integer orgId, Integer customerType, String customerName) {
		Integer customerId = null;
		try {
			customerId = customerService.queryCustomerObj(orgId, customerType, customerName);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return customerId;
	}

}
