package com.chinaitop.depot.customer.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;
import org.springframework.web.client.RestTemplate;

import com.chinaitop.depot.customer.mapper.BusinessCustomerMapper;
import com.chinaitop.depot.customer.model.BusinessCustomer;
import com.chinaitop.depot.customer.model.BusinessCustomerExample;
import com.chinaitop.depot.customer.model.BusinessCustomerExample.Criteria;
import com.chinaitop.depot.customer.service.BusinessCustomerService;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;


@Service
public class BusinessCustomerServiceImpl implements BusinessCustomerService {
	
	@Resource
	private BusinessCustomerMapper customerMapper;
	
	@Resource
    private RestTemplate restTemplate;

	@Value("${jsgjjsjUrl}")
    private String jsgjjsjUrl;
	
	@Override
	public List<BusinessCustomer> queryByExample(BusinessCustomerExample example) {
		return customerMapper.selectByExample(example);
	}

	@Override
	public BusinessCustomer findById(Integer id) {
		return customerMapper.selectByPrimaryKey(id);
	}

	@Override
	public void add(BusinessCustomer customer,  Integer orgId) {
	    customer.setIsInBlacklist(0);
	    customer.setOrgId(orgId);
		customerMapper.insert(customer);
		this.sxtgjjjk(customer.getId(),orgId,"i");
	}

	@Override
	public void update(BusinessCustomer customer) {
		
		customerMapper.updateByPrimaryKey(customer);
		this.sxtgjjjk(customer.getId(),customer.getOrgId(),"u");

	}

	@Override
	public void remove(Integer id,Integer orgId) {
		customerMapper.deleteByPrimaryKey(id);
		
		this.sxtgjjjk(id,orgId,"d");

	}

	// 加入黑名单.
	@Override
    public Map<String, Object> putInBlackList(Integer id) {
        Map<String, Object> returnMap = new HashMap<String, Object>();
        returnMap.put("success", "success");
        BusinessCustomer customer = new BusinessCustomer();
        customer.setId(id);
        customer.setIsInBlacklist(1);
        customerMapper.updateByPrimaryKeySelective(customer);
		this.sxtgjjjk(id,id,"u");

        return returnMap;
    }

    // 移除黑名单.
    @Override
    public Map<String, Object> removeBlackList(Integer id) {
        Map<String, Object> returnMap = new HashMap<String, Object>();
        returnMap.put("success", "success");
        BusinessCustomer customer = new BusinessCustomer();
        customer.setId(id);
        customer.setIsInBlacklist(0);
        customerMapper.updateByPrimaryKeySelective(customer);
		this.sxtgjjjk(id,id,"u");

        return returnMap;
    }

    /**
     * 条件查询.
     */
    @Override
    public List<BusinessCustomer> list(Integer pageNum, Integer pageSize,
            BusinessCustomer customer, Integer orgId) {
        BusinessCustomerExample example = new BusinessCustomerExample();
        Criteria createCriteria = example.createCriteria();
        // 所属机构.
        if (null != orgId) {
        	createCriteria.andOrgIdEqualTo(orgId);
        }

        // 客户名称.
        if (StringUtils.isNotBlank(customer.getName())) {
            createCriteria.andNameLike("%" + customer.getName() + "%");
        }
        // 客户类型.
        if (customer.getClassify() != null) {
            createCriteria.andClassifyEqualTo(customer.getClassify());
        }
        // 是否在黑名单
        if (customer.getIsInBlacklist() != null) {
            createCriteria.andIsInBlacklistEqualTo(customer.getIsInBlacklist());
        }
        // id倒序.
        example.setOrderByClause("id desc");
        if (null != pageNum && null != pageSize) {
        	PageHelper.startPage(pageNum, pageSize);
        }
        
        return customerMapper.selectByExample(example);
    }

	@Override
	public String checkRepeat(Integer orgId, String zjh, Integer customerId, Integer customerType, String customerName)
			throws Exception {
		String flag = "false";
		BusinessCustomerExample example = new BusinessCustomerExample();
		Criteria criteria = example.createCriteria();
		if (null != orgId) {
			criteria.andOrgIdEqualTo(orgId);
		}

		//个人客户，校验身份证号；企业客户，校验统一信用代码
		if (null != customerType) {
			criteria.andClassifyEqualTo(customerType);
			//个人客户的身份证号
			if (customerType.equals(3152)) {
				criteria.andIdentificationEqualTo(zjh);
			}
			//企业客户的统一信用代码
			if (customerType.equals(3153)) {
				criteria.andSocialCreditCodeEqualTo(zjh);
			}
		} else {
			return flag;
		}

		if (null != customerId) {
			criteria.andIdNotEqualTo(customerId);
		}

		if (StringUtils.isNotBlank(customerName)) {
			criteria.andNameEqualTo(customerName);
		}

		List<BusinessCustomer> list =  queryByExample(example);
		if (null == list || list.size() == 0) {
			flag = "true";
		}
		return flag;
	}

	@Override
	public Integer queryCustomerObj(Integer orgId, Integer customerType, String customerName) {
		Integer customerId = null;
		BusinessCustomerExample example = new BusinessCustomerExample();
		Criteria criteria = example.createCriteria();
		if (null != orgId) {
			criteria.andOrgIdEqualTo(orgId);
		}
		if (null != customerType) {
			criteria.andClassifyEqualTo(customerType);
		}
		if (StringUtils.isNotBlank(customerName)) {
			criteria.andNameEqualTo(customerName);
		}
		List<BusinessCustomer> list =  queryByExample(example);
		if (null != list && list.size() > 0) {
			customerId = list.get(0).getId();
		}
		return customerId;
	}
	
	
	/**
   	 * 客户国家局数据
   	 */
       public void sxtgjjjk(Integer id, Integer orgId,String czbz) {
           
         String tableName = "ODS_UP_KHXXJK";
  		/**
           * restTemplate调用
           */
          //String url = "http://localhost:9022/recPublish/sendMessage";//
          //发送post请求，并打印结果，以String类型接收响应结果JSON字符串
  		
          MultiValueMap<String, Object> sendMap = new LinkedMultiValueMap<>();
  		sendMap.add("tableName", tableName);
  		sendMap.add("czbz", czbz);
  		sendMap.add("ywId", id);
  		sendMap.add("orgId", orgId);

          restTemplate.postForObject(jsgjjsjUrl, sendMap, String.class);
       }

}
