package com.chinaitop.depot.grainAnalysis.controller;

import com.chinaitop.depot.grainAnalysis.model.*;
import com.chinaitop.depot.grainAnalysis.service.GrainAnalysisAbnormalService;
import com.chinaitop.depot.grainAnalysis.service.GrainAnalysisService;
import com.chinaitop.depot.grainAnalysis.service.TTestdataService;
import com.chinaitop.depot.keeperAccount.model.StorageAccountRecord;
import com.chinaitop.depot.keeperAccount.service.StorageAccountRecordService;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.http.MediaType;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.text.ParseException;
import java.util.*;

@RestController
@RequestMapping(value="/GrainAnalysis")
@Api(value= "GrainAnalysisController", description = "粮情分析周/月/季")
public class GrainAnalysisController {

	@Resource
	private GrainAnalysisService grainAnalysisService;
	@Resource
	private GrainAnalysisAbnormalService grainAnalysisAbnormalService;
	@Resource
	private TTestdataService tTestdataService;

	@RequestMapping(value="/pageList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="周/月/季报列表", notes = "支持分页")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="pageNum", value="页数", paramType="query"),
    	@ApiImplicitParam(name="pageSize", value="每页显示条数", paramType="query"),
    	@ApiImplicitParam(name="type", value="类型 1:周报 2月报 3季报", paramType="query"),
    	@ApiImplicitParam(name="houseId", value="仓房id", paramType="query"),
    	@ApiImplicitParam(name="jcqsrq", value="起始时间", paramType="query"),
    	@ApiImplicitParam(name="jczzrq", value="结束时间", paramType="query"),
		@ApiImplicitParam(name="jcnf", value="检查年份", paramType="query"),
		@ApiImplicitParam(name="jcyf", value="检查月份", paramType="query"),
		@ApiImplicitParam(name="jcjd", value="检查季度", paramType="query"),
		@ApiImplicitParam(name="orgId", value="组织机构Id", paramType="query")
    })
	public PageInfo<GrainAnalysis> pageList(HttpServletRequest request, Integer pageNum, Integer pageSize,
			Integer type, Integer houseId, @DateTimeFormat(pattern="yyyy-MM-dd")Date jcqsrq, @DateTimeFormat(pattern="yyyy-MM-dd")Date jczzrq,Integer jcnf, Integer jcyf, Integer jcjd,Integer orgId) {
		GrainAnalysisExample example = new GrainAnalysisExample();
		GrainAnalysisExample.Criteria criteria = example.createCriteria();
		if(orgId!=null){
			criteria.andOrgIdEqualTo(orgId);
		}
		if(type!=null){
			criteria.andTypeEqualTo(type);
		}
		if(houseId!=null){
			criteria.andHouseIdEqualTo(houseId);
		}
		if(jcqsrq!=null){
			criteria.andJcqsrqGreaterThanOrEqualTo(jcqsrq);
		}
		if(jczzrq!=null){
			criteria.andJczzrqLessThanOrEqualTo(jcqsrq);
		}
		if(jcnf!=null){
			criteria.andJcnfEqualTo(jcnf);
		}
		if(jcyf!=null){
			criteria.andJcyfEqualTo(jcyf);
		}
		if(jcjd!=null){
			criteria.andJcjdEqualTo(jcjd);
		}

		example.setOrderByClause("create_time desc");
		// 分页
		if (pageNum != null && pageSize != null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		List<GrainAnalysis> list = grainAnalysisService.getList(example);
		PageInfo<GrainAnalysis> pageInfo = new PageInfo<>(list);
		return pageInfo;
	}

	@RequestMapping(value = "/addWeek", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="添加/编辑周报", notes = "添加周报")
    @ApiImplicitParams({
			@ApiImplicitParam(name = "grainAnalysisJson", value = "周报信息", paramType = "form")
    })
	public Map<String, Object> addWeek(String grainAnalysisJson) {
		Map<String, Object> modelMap = new HashMap<>();
		// JSON字符串转对象
		ObjectMapper mapper = new ObjectMapper();
		try {
			GrainAnalysis grainAnalysis = mapper.readValue(grainAnalysisJson, GrainAnalysis.class);
			//异常信息与四无检查
			List<GrainAnalysisAbnormal> grainAnalysisAbnormalList = grainAnalysis.getGrainAnalysisAbnormalList();
			if(grainAnalysis.getId()!=null){
				grainAnalysisService.update(grainAnalysis);
				if(!CollectionUtils.isEmpty(grainAnalysisAbnormalList)){
					for (GrainAnalysisAbnormal grainAnalysisAbnormal : grainAnalysisAbnormalList) {
						grainAnalysisAbnormal.setGrainAnalysisId(grainAnalysis.getId());
						if(grainAnalysisAbnormal.getId()!=null){
							grainAnalysisAbnormalService.update(grainAnalysisAbnormal);
						}else{
							grainAnalysisAbnormalService.save(grainAnalysisAbnormal);
						}
					}
				}
			}else{
				grainAnalysis.setType(1);
				grainAnalysis.setCreateTime(new Date());
				grainAnalysisService.save(grainAnalysis);
				if(!CollectionUtils.isEmpty(grainAnalysisAbnormalList)){
					for (GrainAnalysisAbnormal grainAnalysisAbnormal : grainAnalysisAbnormalList) {
						grainAnalysisAbnormal.setGrainAnalysisId(grainAnalysis.getId());
						grainAnalysisAbnormalService.save(grainAnalysisAbnormal);
					}
				}
			}
			modelMap.put("status", "success");
		} catch (Exception e) {
			modelMap.put("status", "error");
			e.printStackTrace();
		}
		return modelMap;
	}

	@RequestMapping(value = "/addMonth", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="添加/编辑月报", notes = "添加月报")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "grainAnalysisJson", value = "月报信息", paramType = "form")
	})
	public Map<String, Object> addMonth(String grainAnalysisJson) {
		Map<String, Object> modelMap = new HashMap<>();
		// JSON字符串转对象
		ObjectMapper mapper = new ObjectMapper();
		try {
			GrainAnalysis grainAnalysis = mapper.readValue(grainAnalysisJson, GrainAnalysis.class);
			//异常信息与四无检查
			List<GrainAnalysisAbnormal> grainAnalysisAbnormalList = grainAnalysis.getGrainAnalysisAbnormalList();
			if(grainAnalysis.getId()!=null){
				grainAnalysisService.update(grainAnalysis);
				if(!CollectionUtils.isEmpty(grainAnalysisAbnormalList)){
					for (GrainAnalysisAbnormal grainAnalysisAbnormal : grainAnalysisAbnormalList) {
						grainAnalysisAbnormal.setGrainAnalysisId(grainAnalysis.getId());
						if(grainAnalysisAbnormal.getId()!=null){
							grainAnalysisAbnormalService.update(grainAnalysisAbnormal);
						}else{
							grainAnalysisAbnormalService.save(grainAnalysisAbnormal);
						}
					}
				}
			}else{
				grainAnalysis.setType(2);
				grainAnalysis.setCreateTime(new Date());
				grainAnalysisService.save(grainAnalysis);
				if(!CollectionUtils.isEmpty(grainAnalysisAbnormalList)){
					for (GrainAnalysisAbnormal grainAnalysisAbnormal : grainAnalysisAbnormalList) {
						grainAnalysisAbnormal.setGrainAnalysisId(grainAnalysis.getId());
						grainAnalysisAbnormalService.save(grainAnalysisAbnormal);
					}
				}
			}
			modelMap.put("status", "success");
		} catch (Exception e) {
			modelMap.put("status", "error");
			e.printStackTrace();
		}
		return modelMap;
	}

	@RequestMapping(value = "/addQuarter", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="添加/编辑季报", notes = "添加季报")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "grainAnalysisJson", value = "季报信息", paramType = "form")
	})
	public Map<String, Object> addQuarter(String grainAnalysisJson) {
		Map<String, Object> modelMap = new HashMap<>();
		// JSON字符串转对象
		ObjectMapper mapper = new ObjectMapper();
		try {
			GrainAnalysis grainAnalysis = mapper.readValue(grainAnalysisJson, GrainAnalysis.class);
			//异常信息与四无检查
			List<GrainAnalysisAbnormal> grainAnalysisAbnormalList = grainAnalysis.getGrainAnalysisAbnormalList();
			if(grainAnalysis.getId()!=null){
				grainAnalysisService.update(grainAnalysis);
				if(!CollectionUtils.isEmpty(grainAnalysisAbnormalList)){
					for (GrainAnalysisAbnormal grainAnalysisAbnormal : grainAnalysisAbnormalList) {
						grainAnalysisAbnormal.setGrainAnalysisId(grainAnalysis.getId());
						if(grainAnalysisAbnormal.getId()!=null){
							grainAnalysisAbnormalService.update(grainAnalysisAbnormal);
						}else{
							grainAnalysisAbnormalService.save(grainAnalysisAbnormal);
						}
					}
				}
			}else{
				grainAnalysis.setType(3);
				grainAnalysis.setCreateTime(new Date());
				grainAnalysisService.save(grainAnalysis);
				if(!CollectionUtils.isEmpty(grainAnalysisAbnormalList)){
					for (GrainAnalysisAbnormal grainAnalysisAbnormal : grainAnalysisAbnormalList) {
						grainAnalysisAbnormal.setGrainAnalysisId(grainAnalysis.getId());
						grainAnalysisAbnormalService.save(grainAnalysisAbnormal);
					}
				}
			}
			modelMap.put("status", "success");
		} catch (Exception e) {
			modelMap.put("status", "error");
			e.printStackTrace();
		}
		return modelMap;
	}

	@RequestMapping(value="/temperatureData", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="获取温湿度情况列表", notes = "获取温湿度情况列表")
	@ApiImplicitParams({
			@ApiImplicitParam(name="orgId", value="组织机构Id", paramType="query"),
			@ApiImplicitParam(name="jcqsrq", value="起始时间", paramType="query"),
			@ApiImplicitParam(name="jczzrq", value="结束时间", paramType="query"),
			@ApiImplicitParam(name="jcnf", value="检查年份", paramType="query"),
			@ApiImplicitParam(name="jcyf", value="检查月份", paramType="query"),
			@ApiImplicitParam(name="jcjd", value="检查季度", paramType="query"),
			@ApiImplicitParam(name="houseId", value="仓房id", paramType="query")
	})
	public List<TTestdata> temperatureData(HttpServletRequest request, Integer orgId, @DateTimeFormat(pattern="yyyy-MM-dd")Date jcqsrq,
										   @DateTimeFormat(pattern="yyyy-MM-dd")Date jczzrq, Integer jcnf,
										   Integer jcyf, Integer jcjd, Integer houseId) {
		List<TTestdata> list = null;
		try {
			list = tTestdataService.getList(orgId,jcqsrq,jczzrq,jcnf,jcyf,jcjd,houseId);
		} catch (ParseException e) {
			e.printStackTrace();
		}
		return list;
	}

	@RequestMapping(value="/info", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="获取详情", notes = "获取详情")
	@ApiImplicitParams({
			@ApiImplicitParam(name="id", value="主键id", paramType="query")
	})
	public GrainAnalysis info(HttpServletRequest request, Integer id) throws ParseException {
		/* 查询主表数据 */
		GrainAnalysis grainAnalysis = grainAnalysisService.getById(id);

		/* 查询子表数据 */
		GrainAnalysisAbnormalExample example = new GrainAnalysisAbnormalExample();
		GrainAnalysisAbnormalExample.Criteria criteria = example.createCriteria();
		criteria.andGrainAnalysisIdEqualTo(grainAnalysis.getId());
		List<GrainAnalysisAbnormal> grainAnalysisAbnormalList = grainAnalysisAbnormalService.getList(example);

		/* 赋值给异常情况与四无检查 */
		if(!CollectionUtils.isEmpty(grainAnalysisAbnormalList)){
			grainAnalysis.setGrainAnalysisAbnormalList(grainAnalysisAbnormalList);
		}
		List<TTestdata> list = null;
		try {
			list = tTestdataService.getList(grainAnalysis.getOrgId(),grainAnalysis.getJcqsrq(),grainAnalysis.getJczzrq(),
					grainAnalysis.getJcnf(),grainAnalysis.getJcyf(),grainAnalysis.getJcjd(),grainAnalysis.getHouseId());
		} catch (ParseException e) {
			e.printStackTrace();
		}
		if (!CollectionUtils.isEmpty(list)) {
			if (grainAnalysis.getType() == 1) {//周报
				grainAnalysis.settTestdata(list);
			} else if (grainAnalysis.getType() == 2) {//月报
                //查询对应年份月份的周报的数据，然后取每条周报数据所在时间范围内的第一条测温数据
				List<TTestdata> onlyDatas = new ArrayList<>();
				List<GrainAnalysis> grainAnalysisList = grainAnalysisService.getWeekAnalysis(grainAnalysis.getHouseId(), grainAnalysis.getJcnf(), grainAnalysis.getJcyf(), grainAnalysis.getOrgId());
				if(!CollectionUtils.isEmpty(grainAnalysisList) && !CollectionUtils.isEmpty(grainAnalysisAbnormalList)){
					for (GrainAnalysis analysis : grainAnalysisList) {
						if (!CollectionUtils.isEmpty(analysis.gettTestdata())) {
							onlyDatas.addAll(analysis.gettTestdata());
						}
					}
				}
				grainAnalysis.settTestdata(onlyDatas);
			}else{//以下是季报
				List<TTestdata> onlyDatas = new ArrayList<>();
				List<GrainAnalysis> grainAnalysisList = grainAnalysisService.getMonthAnalysis(grainAnalysis.getHouseId(), grainAnalysis.getJcnf(), grainAnalysis.getJcjd(), grainAnalysis.getOrgId());
				if(!CollectionUtils.isEmpty(grainAnalysisList) && !CollectionUtils.isEmpty(grainAnalysisAbnormalList)){
					for (GrainAnalysis analysis : grainAnalysisList) {
						if (!CollectionUtils.isEmpty(analysis.gettTestdata())) {
							onlyDatas.addAll(analysis.gettTestdata());
						}
					}
				}
				grainAnalysis.settTestdata(onlyDatas);
			}

		}
		return grainAnalysis;
	}

	@RequestMapping(value="/getWeekAnalysis", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="获取指定日期内有几个周报", notes = "获取指定日期内有几个周报")
	@ApiImplicitParams({
			@ApiImplicitParam(name="houseId", value="仓房id", paramType="query"),
			@ApiImplicitParam(name="jcnf", value="检查年份", paramType="query"),
			@ApiImplicitParam(name="jcyf", value="检查月份", paramType="query"),
			@ApiImplicitParam(name="orgId", value="组织机构Id", paramType="query")
	})
	public List<GrainAnalysis> getWeekAnalysis(HttpServletRequest request, Integer houseId, Integer jcnf, Integer jcyf,
										 Integer orgId) {
		List<GrainAnalysis> grainAnalysis = null;
		try {
			grainAnalysis = grainAnalysisService.getWeekAnalysis(houseId, jcnf, jcyf, orgId);
		} catch (ParseException e) {
			e.printStackTrace();
		}
		return grainAnalysis;
	}

	@RequestMapping(value="/getMonthAnalysis", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="获取指定日期内上报了几个月报", notes = "获取指定日期内上报了几个月报")
	@ApiImplicitParams({
			@ApiImplicitParam(name="houseId", value="仓房id", paramType="query"),
			@ApiImplicitParam(name="jcnf", value="检查年份", paramType="query"),
			@ApiImplicitParam(name="jcjd", value="检查季度", paramType="query"),
			@ApiImplicitParam(name="orgId", value="组织机构Id", paramType="query")
	})
	public List<GrainAnalysis> getMonthAnalysis(HttpServletRequest request, Integer houseId, Integer jcnf, Integer jcjd,
											   Integer orgId) {
		List<GrainAnalysis> grainAnalysis = grainAnalysisService.getMonthAnalysis(houseId, jcnf, jcjd, orgId);
		return grainAnalysis;
	}



}
