package com.chinaitop.depot.grainAnalysis.service.impl;

import com.chinaitop.depot.grainAnalysis.mapper.GrainAnalysisMapper;
import com.chinaitop.depot.grainAnalysis.model.GrainAnalysis;
import com.chinaitop.depot.grainAnalysis.model.GrainAnalysisExample;
import com.chinaitop.depot.grainAnalysis.model.TTestdata;
import com.chinaitop.depot.grainAnalysis.service.GrainAnalysisService;
import com.chinaitop.depot.grainAnalysis.service.TTestdataService;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

@Service
public class GrainAnalysisServiceImpl implements GrainAnalysisService {

	@Resource
	private GrainAnalysisMapper grainAnalysisMapper;
	@Resource
	private TTestdataService tTestdataService;

	@Override
	public List<GrainAnalysis> getList(GrainAnalysisExample example) {
		return grainAnalysisMapper.selectByExample(example);
	}

	@Override
	public void save(GrainAnalysis grainAnalysisAbnormal) {
		grainAnalysisMapper.insert(grainAnalysisAbnormal);
	}

	@Override
	public void update(GrainAnalysis grainAnalysisAbnormal) {
		grainAnalysisMapper.updateByPrimaryKey(grainAnalysisAbnormal);
	}

	@Override
	public GrainAnalysis getById(Integer id) {
		return grainAnalysisMapper.selectByPrimaryKey(id);
	}

	@Override
	public List<GrainAnalysis> getMonthAnalysis(Integer houseId, Integer jcnf, Integer jcjd, Integer orgId) {
		GrainAnalysisExample example = new GrainAnalysisExample();
		GrainAnalysisExample.Criteria criteria = example.createCriteria();
		if(orgId!=null){
			criteria.andOrgIdEqualTo(orgId);
		}
		criteria.andTypeEqualTo(2);
		if(houseId!=null){
			criteria.andHouseIdEqualTo(houseId);
		}
		if(jcnf!=null){
			criteria.andJcnfEqualTo(jcnf);
		}
		if(jcjd !=null ){
			if(jcjd == 1){
				criteria.andJcyfGreaterThanOrEqualTo(1);
				criteria.andJcyfLessThanOrEqualTo(3);
			}else if(jcjd == 2){
				criteria.andJcyfGreaterThanOrEqualTo(4);
				criteria.andJcyfLessThanOrEqualTo(6);
			}else if(jcjd == 3){
				criteria.andJcyfGreaterThanOrEqualTo(7);
				criteria.andJcyfLessThanOrEqualTo(9);
			}else {
				criteria.andJcyfGreaterThanOrEqualTo(10);
				criteria.andJcyfLessThanOrEqualTo(12);
			}
		}
		example.setOrderByClause("jcyf desc");
		List<GrainAnalysis> list = grainAnalysisMapper.selectByExample(example);
		if(!CollectionUtils.isEmpty(list)){
			for (GrainAnalysis grainAnalysis : list) {
				List<TTestdata> tTestdata = null;
				try {
					tTestdata = tTestdataService.getList(orgId,null,null,grainAnalysis.getJcnf(),grainAnalysis.getJcyf(),null,houseId);
				} catch (ParseException e) {
					e.printStackTrace();
				}
				if(!CollectionUtils.isEmpty(tTestdata)){
					TTestdata onlyData = tTestdata.get(0);
					List<TTestdata> onlyDatas = new ArrayList<>();
					onlyDatas.add(onlyData);
					grainAnalysis.settTestdata(onlyDatas);
				}
			}
		}
		return list;
	}

	@Override
	public List<GrainAnalysis> getWeekAnalysis(Integer houseId, Integer jcnf, Integer jcyf, Integer orgId) throws ParseException {
		GrainAnalysisExample example = new GrainAnalysisExample();
		GrainAnalysisExample.Criteria criteria = example.createCriteria();
		if(orgId!=null){
			criteria.andOrgIdEqualTo(orgId);
		}
		criteria.andTypeEqualTo(1);
		if(houseId!=null){
			criteria.andHouseIdEqualTo(houseId);
		}
		Date startDate = null;
		Date endDate = null;
		if(jcnf!=null && jcyf!=null){
			startDate = getFirstDayOfMonth(jcnf,jcyf);
			endDate = getLastDayOfMonth(jcnf,jcyf);
		}
		if(startDate!=null){
			criteria.andJcqsrqGreaterThanOrEqualTo(startDate);
		}
		if(endDate!=null){
			criteria.andJcqsrqLessThanOrEqualTo(endDate);
		}
		example.setOrderByClause("jcqsrq desc");
		List<GrainAnalysis> list = grainAnalysisMapper.selectByExample(example);
		if(!CollectionUtils.isEmpty(list)){
			for (GrainAnalysis grainAnalysis : list) {
				List<TTestdata> tTestdata = tTestdataService.getList(orgId,grainAnalysis.getJcqsrq(),grainAnalysis.getJczzrq(),null,null,null,houseId);
				if(!CollectionUtils.isEmpty(tTestdata)){
					TTestdata onlyData = tTestdata.get(0);
					List<TTestdata> onlyDatas = new ArrayList<>();
					onlyDatas.add(onlyData);
					grainAnalysis.settTestdata(onlyDatas);
				}
			}
		}
		return list;
	}

	//获取某年某月第一天
	public static Date getFirstDayOfMonth(Integer jcnf, Integer jcyf) throws ParseException {
		Calendar cal = Calendar.getInstance();
		cal.set(Calendar.YEAR,jcnf);    //设置年份
		cal.set(Calendar.MONTH, jcyf-1);  //设置月份
		int firstDay = cal.getActualMinimum(Calendar.DAY_OF_MONTH); //获取某月最小天数
		cal.set(Calendar.DAY_OF_MONTH, firstDay);   //设置日历中月份的最小天数
		//格式化日期
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd 00:00:00");
		return sdf.parse(sdf.format(cal.getTime()));

	}

	//获取某年某月最后一天
	public static Date getLastDayOfMonth(Integer jcnf, Integer jcyf) throws ParseException {

		Calendar cal = Calendar.getInstance();
		cal.set(Calendar.YEAR,jcnf);    //设置年份
		cal.set(Calendar.MONTH, jcyf-1);  //设置月份
		int lastDay = cal.getActualMaximum(Calendar.DAY_OF_MONTH);  //获取某月最大天数
		cal.set(Calendar.DAY_OF_MONTH, lastDay);    //设置日历中月份的最大天数
		//格式化日期
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd 23:59:59");
		return sdf.parse(sdf.format(cal.getTime()));
	}
}
