package com.chinaitop.depot.grainAnalysis.service.impl;

import com.chinaitop.depot.grainAnalysis.mapper.BasicStorehouseMapper;
import com.chinaitop.depot.grainAnalysis.mapper.GrainAnalysisMapper;
import com.chinaitop.depot.grainAnalysis.mapper.TTestdataMapper;
import com.chinaitop.depot.grainAnalysis.model.*;
import com.chinaitop.depot.grainAnalysis.service.GrainAnalysisService;
import com.chinaitop.depot.grainAnalysis.service.TTestdataService;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

@Service
public class TTestdateServiceImpl implements TTestdataService {

	@Resource
	private TTestdataMapper tTestdataMapper;
	@Resource
	private BasicStorehouseMapper basicStorehouseMapper;

	@Override
	public List<TTestdata> getList(Integer orgId, Date jcqsrq, Date jczzrq, Integer jcnf, Integer jcyf, Integer jcjd, Integer houseId) throws ParseException {
		TTestdataExample example = new TTestdataExample();
		TTestdataExample.Criteria criteria = example.createCriteria();
		BasicStorehouseExample basicStorehouseExample = new BasicStorehouseExample();
		BasicStorehouseExample.Criteria basicStorehouseExampleCriteria = basicStorehouseExample.createCriteria();
		if(orgId!=null){
			criteria.andOrgIdEqualTo(orgId.toString());
			basicStorehouseExampleCriteria.andOrgIdEqualTo(orgId);
		}
		if(houseId!=null){
			basicStorehouseExampleCriteria.andStorehouseIdEqualTo(houseId);
		}
		List<BasicStorehouse> basicStorehouseList = basicStorehouseMapper.selectByExample(basicStorehouseExample);
		if(CollectionUtils.isEmpty(basicStorehouseList)){
			return null;
		}
		BasicStorehouse basicStorehouse = basicStorehouseList.get(0);
		criteria.andHouseEqualTo(basicStorehouse.getStorehouseCode());
		criteria.andIlqYqEqualTo("0");
		if(jcnf!=null && jcyf!=null){
			jcqsrq = getFirstDayOfMonth(jcnf,jcyf);//获取某年某月第一天
			jczzrq = getLastDayOfMonth(jcnf,jcyf);//获取某年某月最后一天
		}
		if(jcnf!=null && jcjd!=null){
			Integer qsyf = 0;
			Integer zzyf = 0;
			if(jcjd == 1){
				qsyf = 1;
				zzyf = 3;
			}else if(jcjd == 2){
				qsyf = 4;
				zzyf = 6;
			}else if(jcjd == 3){
				qsyf = 7;
				zzyf = 9;
			}else{
				qsyf = 10;
				zzyf = 12;
			}
			jcqsrq = getFirstDayOfMonth(jcnf,qsyf);
			jczzrq = getLastDayOfMonth(jcnf,zzyf);
		}
		if(jcqsrq!=null){
			String first=first(jcqsrq);
			SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
			Date firstDate =sdf.parse(first);
			criteria.andTTimeGreaterThanOrEqualTo(firstDate);
		}
		if(jczzrq!=null){
			String last=last(jczzrq);
			SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
			Date lastDate =sdf.parse(last);
			criteria.andTTimeLessThanOrEqualTo(lastDate);
		}
		example.setOrderByClause("t_time asc");
		List<TTestdata> tTestdataList = tTestdataMapper.selectByExample(example);
		List<TTestdata> resultList = null;

		/* 每天只返回一条数据 */
		if(!CollectionUtils.isEmpty(tTestdataList)){
			resultList = new ArrayList<>();
			Map<String,String> map = new HashMap<>();
			SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
			for (TTestdata tTestdata : tTestdataList) {
				String date = sdf.format(tTestdata.gettTime());
				//每天只返回一条数据
				if(map.get(date)==null){
					resultList.add(tTestdata);
					map.put(date,date);
				}
			}
		}
		return resultList;
	}

	//设置时间为 00:00:00
	public static  String first(Date date) throws ParseException {
		//格式化日期
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd 00:00:00");
		return sdf.format(date);
	}

	//设置时间为 23:59:59
	public static String last(Date date) throws ParseException {
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd 23:59:59");
		return sdf.format(date);
	}

	//获取某年某月第一天
	public static  Date getFirstDayOfMonth(Integer jcnf, Integer jcyf) throws ParseException {
		Calendar cal = Calendar.getInstance();
		cal.set(Calendar.YEAR,jcnf);    //设置年份
		cal.set(Calendar.MONTH, jcyf-1);  //设置月份
		int firstDay = cal.getActualMinimum(Calendar.DAY_OF_MONTH); //获取某月最小天数
		cal.set(Calendar.DAY_OF_MONTH, firstDay);   //设置日历中月份的最小天数
		//格式化日期
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd 00:00:00");
		return sdf.parse(sdf.format(cal.getTime()));

	}

	//获取某年某月最后一天
	public static Date getLastDayOfMonth(Integer jcnf, Integer jcyf) throws ParseException {

		Calendar cal = Calendar.getInstance();
		cal.set(Calendar.YEAR,jcnf);    //设置年份
		cal.set(Calendar.MONTH, jcyf-1);  //设置月份
		int lastDay = cal.getActualMaximum(Calendar.DAY_OF_MONTH);  //获取某月最大天数
		cal.set(Calendar.DAY_OF_MONTH, lastDay);    //设置日历中月份的最大天数
		//格式化日期
		SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd 23:59:59");
		return sdf.parse(sdf.format(cal.getTime()));
	}
}
