package com.chinaitop.depot.keeperAccount.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.ObjectUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.keeperAccount.model.StorageAccountRecord;
import com.chinaitop.depot.keeperAccount.service.StorageAccountRecordService;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

@RestController
@RequestMapping(value="/StorageAccountRecord")
@Api(value= "StorageAccountRecordController", description = "保管账记账控制类")
public class StorageAccountRecordController {

	@Resource
	private StorageAccountRecordService recordService;

	@RequestMapping(value="/sumAccountList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="保管总账列表，按月统计", notes = "支持分页")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="pageNum", value="页数", paramType="query"),
    	@ApiImplicitParam(name="pageSize", value="每页显示条数", paramType="query"),
    	@ApiImplicitParam(name="lspz", value="粮食品种", paramType="query"),
    	@ApiImplicitParam(name="lsxz", value="粮食性质", paramType="query"),
    	@ApiImplicitParam(name="startDate", value="起始时间", paramType="query"),
    	@ApiImplicitParam(name="endDate", value="结束时间", paramType="query")
    })
	public PageInfo<Map<String, Object>> sumAccountList(HttpServletRequest request, Integer pageNum, Integer pageSize, 
			Integer lspz, Integer lsxz, String startDate, String endDate) {
		Map<String, Object> map = new HashMap<String, Object>();
		if (lspz != null) {
			map.put("pz", lspz+"");
		}
		if (lsxz != null) {
			map.put("hwxz", lsxz+"");
		}
		if (pageNum!=null && pageSize!=null) {
			PageHelper.startPage(pageNum, pageSize);
		}
		String orgId = ObjectUtils.toString(request.getSession().getAttribute("orgId"),"");
		map.put("orgId", orgId);
		List<Map<String, Object>> list = recordService.selectKeepSumAccountData(map);
		if (null != list && list.size() > 0) {
			Map<String, Object> kcsl_map = null;
			List<Map<String, Object>> group_list = null;
			List<Map<String, Object>> kcsl_list = null;
			double kcsl = 0d;
			for (Map<String, Object> obj : list) {
				kcsl_map = new HashMap<String, Object>();
				kcsl_map.put("pz", obj.get("lspz"));
				kcsl_map.put("hwxz", obj.get("hwxz"));
				kcsl_map.put("rq", obj.get("rq"));
				kcsl_map.put("orgId", orgId == "" ? null : Integer.parseInt(orgId));
				Map<String, Object> map1 = new HashMap<String, Object>();
				map1 = recordService.selectOrCheckStorageAccountRecord(request, null, null, (Integer)obj.get("hwxz"), (Integer)obj.get("lspz"), (String)obj.get("rq"), 1, map1, Integer.parseInt(orgId));
				if(map1.get("obj") !=null){
					StorageAccountRecord record= (StorageAccountRecord) map1.get("obj");
					obj.put("accountingPerson",record.getAccountingPerson());
					obj.put("auditor",record.getAuditor());
				}
				//查询这个条件下有多少分组，然后把所有分组的数据相加
				group_list = recordService.selectAccountGroup(kcsl_map);
				if (null != group_list && group_list.size() > 0) {
					for (Map<String, Object> gop : group_list) {
						kcsl_map.put("houseId", gop.get("house_id"));
						kcsl_map.put("wareId", gop.get("ware_id"));
						kcsl_list = recordService.selectKCSL(kcsl_map);
						if (null != kcsl_list && kcsl_list.size() > 0) {
							kcsl = kcsl + Double.parseDouble(kcsl_list.get(0).get("kcsl")+"");
						}
					}
					obj.put("kcsl", kcsl);
					kcsl = 0d;
				}
			}
		}
		PageInfo<Map<String, Object>> pageInfo = new PageInfo<Map<String, Object>>(list);
		return pageInfo;
	}

	@RequestMapping(value = "/edit", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询一条记账数据", notes = "查询一条记账数据")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="houseId", value="仓房ID", paramType="query"),
    	@ApiImplicitParam(name="wareId", value="货位ID", paramType="query"),
    	@ApiImplicitParam(name="hwxz", value="粮食性质", paramType="query"),
    	@ApiImplicitParam(name="lspz", value="粮食品种", paramType="query"),
    	@ApiImplicitParam(name="rq", value="日期", paramType="query"),
    	@ApiImplicitParam(name="accountType", value="记账类型", paramType="query"),
		@ApiImplicitParam(name="orgId", value="组织机构ID", paramType="query")
    })
	public Map<String, Object> edit(HttpServletRequest request, String houseId, String wareId,
									Integer hwxz, Integer lspz, String rq,
									Integer accountType, Integer orgId) {
		Map<String, Object> map = new HashMap<String, Object>();
		
		map = recordService.selectOrCheckStorageAccountRecord(request, houseId, wareId, hwxz, lspz, rq, accountType, map, orgId);

		return map;
	}

	@RequestMapping(value = "/update", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="记账", notes = "记账")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="recordJson", value="数据集", paramType="form"),
    	@ApiImplicitParam(name="accountType", value="记账类型", paramType="form"),
    	@ApiImplicitParam(name="orgId", value="单位ID", paramType="form")
    })
	public Map<String, Object> update(String recordJson, Integer accountType, Integer orgId) {
		Map<String, Object> map = new HashMap<String, Object>();
		ObjectMapper mapper = new ObjectMapper();
		try {
			StorageAccountRecord record = mapper.readValue(recordJson, StorageAccountRecord.class);
			if (record.getId() == null) {
				record.setAccountType(accountType);
				record.setOrgId(orgId);
				recordService.add(record);
			} else {
				recordService.update(record);
			}
			map.put("status", "success");
			map.put("msg", "保存成功！");
		} catch (Exception e) {
			e.printStackTrace();
		}
		return map;
	}
}
