package com.chinaitop.depot.keeperAccount.controller;

import com.chinaitop.depot.keeperAccount.model.StorageKeepVoucher;
import com.chinaitop.depot.keeperAccount.service.StorageKeepVoucherService;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@Api(value= "StorageKeepVoucherController", description = "记账凭证控制类")
@RequestMapping(value = "/storageKeepVoucherController")
public class StorageKeepVoucherController {

    private static final Logger logger = LoggerFactory.getLogger(StorageKeepVoucherController.class);

    @Resource
    private StorageKeepVoucherService storageKeepVoucherService;

    @RequestMapping(value="/getList", produces = MediaType.APPLICATION_JSON_VALUE, method= RequestMethod.GET)
    @ApiOperation(value="记账凭证列表", notes = "支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name="pageNum", value="页数", paramType="query"),
            @ApiImplicitParam(name="pageSize", value="每页显示条数", paramType="query"),
            @ApiImplicitParam(name="ch", value="仓房或油罐ID", paramType="query"),
            @ApiImplicitParam(name="hwh", value="货位ID", paramType="query"),
            @ApiImplicitParam(name="orgId", value="组织机构ID", paramType="query")
    })
    public PageInfo<StorageKeepVoucher> getList(Integer pageNum, Integer pageSize,
                                                Integer ch, Integer hwh, Integer orgId) {

        PageInfo<StorageKeepVoucher> pageInfo = null;
        List<StorageKeepVoucher> list = null;
        try {
            if (pageNum!=null && pageSize!=null) {
                PageHelper.startPage(pageNum, pageSize);
            }
            list = storageKeepVoucherService.getList(ch, hwh, orgId, null);
            pageInfo = new PageInfo<>(list);
        } catch (Exception e) {
            //e.printStackTrace();
            logger.error(e.getMessage(), e);
        }

        return pageInfo;
    }

    @RequestMapping(value="/getStorageKeepVoucher", produces = MediaType.APPLICATION_JSON_VALUE, method= RequestMethod.GET)
    @ApiOperation(value="按主键查询一条记账凭证")
    @ApiImplicitParams({
        @ApiImplicitParam(name="id", value="主键唯一ID", paramType="query")
    })
    public StorageKeepVoucher getStorageKeepVoucher(String id) {

        StorageKeepVoucher storageKeepVoucher = null;

        try {
            storageKeepVoucher = storageKeepVoucherService.findByIdCondition(id);
        } catch (Exception e) {
            //e.printStackTrace();
            logger.error(e.getMessage(), e);
        }

        return storageKeepVoucher;
    }

    @RequestMapping(value="/updateStorageKeepVoucher", produces = MediaType.APPLICATION_JSON_VALUE, method= RequestMethod.POST)
    @ApiOperation(value="更新一条记账凭证")
    @ApiImplicitParams({
        @ApiImplicitParam(name="storageKeepVoucherJson", value="数据对象JSON", paramType="query")
    })
    public Map<String, Object> updateStorageKeepVoucher(String storageKeepVoucherJson) {

        Map<String, Object> map = new HashMap<>();

        ObjectMapper objectMapper = new ObjectMapper();
        try {
            StorageKeepVoucher storageKeepVoucherObj = objectMapper.readValue(storageKeepVoucherJson, StorageKeepVoucher.class);
            storageKeepVoucherService.addOrUpdate(storageKeepVoucherObj);
            map.put("msg", "操作成功");
        } catch (IOException e) {
            logger.error(e.getMessage(), e);
            map.put("msg", "操作失败");
        } catch (Exception e) {
            //e.printStackTrace();
            logger.error(e.getMessage(), e);
            map.put("msg", "操作失败");
        }

        return map;
    }

    @RequestMapping(value="/findByCondition", produces = MediaType.APPLICATION_JSON_VALUE, method= RequestMethod.GET)
    @ApiOperation(value="查询保管明细账的一条数据是否已经生成记账凭证")
    @ApiImplicitParams({
            @ApiImplicitParam(name="yDataid", value="出入库fcbgz表的唯一ID", paramType="query")
    })
    public List<StorageKeepVoucher> findByCondition(String yDataid) {

        List<StorageKeepVoucher> list = null;

        try {
            list = storageKeepVoucherService.getList(null, null, null, yDataid);
        } catch (Exception e) {
            //e.printStackTrace();
            logger.error(e.getMessage(), e);
        }

        return list;
    }
}
