package com.chinaitop.depot.profitlossStatement.controller;


import com.chinaitop.depot.profitlossStatement.model.StorageProfitlossStatement;
import com.chinaitop.depot.profitlossStatement.service.StorageProfitlossStatementService;
import com.chinaitop.depot.utils.HistoryList;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 损溢单审批
 * @author My Sunshine
 *
 */
@RestController
@RequestMapping(value="/storageProStateAudit")
@Api(value= "StorageProStateAuditController", description = "损溢单审批管理")
public class StorageProStateAuditController {
    
	@Resource
    private StorageProfitlossStatementService storageProfitlossStatementService;
	
    
    /**
     * 获取审批列表.
     * @param pageNum 页码
     * @param pageSize 每页显示条数
     * @return
     */
    @RequestMapping(value="/getList",  method=RequestMethod.GET)
	@ApiOperation(value="获取损溢单审批列表", notes = "查询数据列表，支持分页")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
		@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
		@ApiImplicitParam(name = "userId", value = "当前登录人的id", paramType = "query")
	})
    public PageInfo<StorageProfitlossStatement> getList(Integer pageNum, Integer pageSize,HttpServletRequest request,StorageProfitlossStatement storageProfitlossStatement,Integer userId) {
    	
    	//PageHelper.startPage(pageNum, pageSize);
    	List<StorageProfitlossStatement> list = new ArrayList<StorageProfitlossStatement>();
        
    	
        List<Map<String,String>> userRoleList = storageProfitlossStatementService.getUserRole(userId);

        String roleNames = "";
        for (Map<String, String> map : userRoleList) {
        	String roleName =  map.get("role_name");
        	roleNames = roleNames + roleName+",";
		}
       // System.out.println(roleNames);
        List<StorageProfitlossStatement> listAll = storageProfitlossStatementService.queryByExample(pageNum,pageSize,storageProfitlossStatement);
        for (StorageProfitlossStatement proStatement : listAll) {
        	//1仓储部经理审批 2质检部经理审批 3统计经理审批 4会计审批 5库领导审批
			if(proStatement.getAuditState().equals(1)){
				if(roleNames.contains("仓储部经理")){
					list.add(proStatement);
				}
			 }
			if(proStatement.getAuditState().equals(2)){
				if(roleNames.contains("质检部经理")){
					list.add(proStatement);
				}
			 }
			if(proStatement.getAuditState().equals(3)){
				if(roleNames.contains("统计部经理")){
					list.add(proStatement);
				}
			 }
			if(proStatement.getAuditState().equals(4)){
				if(roleNames.contains("会计")){
					list.add(proStatement);
				}
			 }
			if(proStatement.getAuditState().equals(5)){
				if(roleNames.contains("库领导")){
					list.add(proStatement);
				}
			 }
		}
        
        PageHelper.startPage(pageNum, pageSize);
        PageInfo<StorageProfitlossStatement> pageInfo = new PageInfo<StorageProfitlossStatement>(list);
        if(pageInfo.getTotal()>0){
        	pageInfo.setStartRow(pageInfo.getStartRow()+1);
        	pageInfo.setEndRow(pageInfo.getEndRow()+1);
        }
        return pageInfo;
    }
    
    /**
     * 获取审批页面详情.
     * @param id  业务主键
     * @param processInstanceId 流程实例id
     * @return
     */
    @RequestMapping(value="/getAudit", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="获取审批页面详情", notes = "获取审批页面详情")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "原数据的id", paramType = "query")
	})
    public Map<String, Object> getAduit(String id) {
        Map<String, Object> modelMap = new HashMap<String, Object>();
        // 详情.
        StorageProfitlossStatement storageProfitlossStatement = storageProfitlossStatementService.findById(id);
        modelMap.put("storageProfitlossStatement", storageProfitlossStatement);
        
        modelMap.put("taskId", storageProfitlossStatement.getId());
        // 审批历史.
        List<HistoryList> auditList = storageProfitlossStatementService.getAudit(modelMap);
        modelMap.put("auditList", auditList);
        
        return modelMap;
    }

    /**
     * 审批.
     * @param profitlossStatementJson 业务主体
     * @param result 当前环节审批结果
     * @return
     */
    @RequestMapping(value="/audit", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="审批", notes = "审批")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="profitlossStatementJson", value="原数据", paramType="form"),
    	@ApiImplicitParam(name="content", value="审批意见", paramType="form"),
    	@ApiImplicitParam(name="userId", value="当前登录人id", paramType="form"),
    	@ApiImplicitParam(name="realName", value="前登录人姓名", paramType="form")
    })
    public Map<String, Object> audit(HttpServletRequest request, 
    		String profitlossStatementJson, Integer userId, String realName,String auditResult,
    		String content,String orgName) {
       
    	
    	Map<String, Object> modelMap = new HashMap<String, Object>();
            // JSON字符串转对象
        ObjectMapper mapper = new ObjectMapper();
        StorageProfitlossStatement storageProfitlossStatement;
		try {
			storageProfitlossStatement = (StorageProfitlossStatement)mapper.readValue(profitlossStatementJson, StorageProfitlossStatement.class);
			modelMap = storageProfitlossStatementService.audit(storageProfitlossStatement, userId,realName,auditResult,content,orgName);

		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
       
        return modelMap;
    }

 

    
}
