package com.chinaitop.depot.profitlossStatement.controller;


import com.chinaitop.depot.profitlossStatement.model.StorageProfitlossStatement;
import com.chinaitop.depot.profitlossStatement.service.StorageProfitlossStatementService;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;

/**
 * 损溢单
 * @author My Sunshine
 *
 */
@RestController
@RequestMapping(value="/storageProfitlossStatement")
@Api(value= "StorageProfitlossStatementController", description = "损溢单申请")

public class StorageProStatementController {

    @Resource
    private StorageProfitlossStatementService storageProfitlossStatementService;

    /**
     * 查找申请列表
     * @param pageNum  页码
     * @param pageSize 每页显示条数
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getList",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
    @ApiOperation(value="损溢单申请列表", notes = "查询数据列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query")
    })
    public PageInfo<StorageProfitlossStatement> getList(Integer pageNum, Integer pageSize,HttpServletRequest request, StorageProfitlossStatement storageProfitlossStatement) throws Exception {

        List<StorageProfitlossStatement> list = storageProfitlossStatementService.queryByExample(pageNum, pageSize,storageProfitlossStatement);
        PageInfo<StorageProfitlossStatement> pageInfo = new PageInfo<StorageProfitlossStatement>(list);
        return pageInfo;
    }


    
    @RequestMapping(value = "/jsRksfzzData", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "入库水分计算记录查询", notes = "入库水分计算查询，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "粮库ID", paramType = "query")
    })
    public PageInfo<Map<String, Object>> jsRksfzzData(Integer pageNum, Integer pageSize,String ch,String hwh,String dycrksj,String zhycRksj, String orgId) {
        Map<String, Object> map = new HashMap<String, Object>();
        if (ch != null && !"".equals(ch)) {
            map.put("ch", ch);
        }
        if (hwh != null && !"".equals(hwh)) {
            map.put("hwh", hwh);
        }
        if (dycrksj != null && !"".equals(dycrksj)) {
            map.put("dycrksj", dycrksj);
        }
        if (zhycRksj != null && !"".equals(zhycRksj)) {
            map.put("zhycRksj", zhycRksj);
        }
        if (orgId != null && !"".equals(orgId)) {
            map.put("orgId", orgId);
        }
        if (pageNum != null && pageSize != null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<Map<String, Object>> list = storageProfitlossStatementService.jsRksfzzData(map);
        PageInfo<Map<String, Object>> pageInfo = new PageInfo<Map<String, Object>>(list);
        return pageInfo;
    }

    @RequestMapping(value = "/getCksl", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "出库数量计算记录查询", notes = "出库数量计算查询，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "粮库ID", paramType = "query")
    })
    public List<Map<String, Object>> getCksl(Integer ch,Integer hwh,String rksj,Integer orgId) {
        Map<String, Object> map = new HashMap<String, Object>();
        if (ch != null && !"".equals(ch)) {
            map.put("ch", ch);
        }
        if (hwh != null && !"".equals(hwh)) {
            map.put("hwh", hwh);
        }
        if (rksj != null && !"".equals(rksj)) {
            map.put("rksj", rksj);
        }
        if (orgId != null && !"".equals(orgId)) {
            map.put("orgId", orgId);
        }
        map.put("dqsj", new Date());
        List<Map<String, Object>> list = storageProfitlossStatementService.getCksl(map);
        return list;
    }
    
    
    /** 保存
     * @param profitlossStatementJson 保存数据json
     * @param  orgId
     * @return
     * @throws JsonParseException
     * @throws JsonMappingException
     * @throws IOException
     */
    @RequestMapping(value="/save",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
    @ApiOperation(value="保存数据", notes = "保存")
    @SuppressWarnings("unchecked")
    @ApiImplicitParams({
            @ApiImplicitParam(name="profitlossStatementJson", value="数据", paramType="form"),
            @ApiImplicitParam(name="orgId", value="当前登录人的组织id", paramType="form")
    })
    public Map<String, Object> save(String profitlossStatementJson, Integer orgId,HttpServletRequest request) 
    		throws JsonParseException, JsonMappingException, IOException {
                                    
                                    
        Map<String, Object> returnMap = new HashMap<String, Object>();
        int a = 0;
        try {
            // JSON字符串转对象
            ObjectMapper mapper = new ObjectMapper();
            StorageProfitlossStatement storageProfitlossStatement = (StorageProfitlossStatement)mapper.readValue(profitlossStatementJson, StorageProfitlossStatement.class);


            Date date = new Date();
            SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyyMMdd");
            String dateStr = simpleDateFormat.format(date);
            if (storageProfitlossStatement.getId() == null) {
            	storageProfitlossStatement.setId(UUID.randomUUID().toString().replace("-", ""));
            	storageProfitlossStatement.setAuditState(0);//待提交
            	storageProfitlossStatement.setOrgId(orgId);//单位id
            	storageProfitlossStatement.setCreateTime(date);
            	storageProfitlossStatement.setUpdateTime(date);
            	if(storageProfitlossStatement.getHwid() != null){
            		storageProfitlossStatement.setSydh(storageProfitlossStatement.getHwid()+""+dateStr+"000");
            	}else{
            		storageProfitlossStatement.setSydh(storageProfitlossStatement.getCforyg()+""+dateStr+"000");
            	}
            	
                a =  storageProfitlossStatementService.add(storageProfitlossStatement);
                
            } else {
            	storageProfitlossStatement.setUpdateTime(date);
            	a = storageProfitlossStatementService.update(storageProfitlossStatement);
            }
            
            
            if (a>0) {
            	returnMap.put("status", "success");
            	
            }else{
            	returnMap.put("status", "error");
            	returnMap.put("msg", "保存失败！");
            }
        } catch (Exception e) {
            e.printStackTrace();
            returnMap.put("status", "error");
            returnMap.put("msg", "保存失败！");
            return returnMap;
        }
        return returnMap;
    }


    /**
	 * 删除
	 * @param id 主键
	 * @return
	 * @throws JsonParseException
	 * @throws JsonMappingException
	 * @throws IOException
	 */
	@RequestMapping(value="/remove", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="删除", notes = "根据id删除")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "id", paramType = "query")
	})
	public Map<String, Object> remove(String id) throws JsonParseException, JsonMappingException, IOException {
		Map<String, Object> modelMap = new HashMap<String, Object>();
		if (id != null) {
			int a = storageProfitlossStatementService.remove(id);
			if(a>0){
				modelMap.put("status", "success");
			}else{
				modelMap.put("status", "error");
			}
		}
		
		return modelMap;
	}

	
	/**
	 * 根据id查找
	 * @param id 主键
	 * @return
	 */
	@RequestMapping(value="/edit", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="根据id查找", notes = "根据id查找")
	@ApiImplicitParams({
		@ApiImplicitParam(name = "id", value = "id", paramType = "query")
	})
	public StorageProfitlossStatement edit(String id) {
		StorageProfitlossStatement storageProfitlossStatement = new StorageProfitlossStatement();
		if (id != null) {
			storageProfitlossStatement = storageProfitlossStatementService.findById(id);
		}
		return storageProfitlossStatement;
	}
	
	
   /**
     * 提交
     * @param profitlossStatement 业务主体
     * @return
     */
    @RequestMapping(value="/submit",produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
    @ApiOperation(value="损溢单提交", notes = "损溢单提交")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "profitlossStatement", value = "业务主体", paramType = "query")
    })
    public Map<String, Object> submit(String profitlossStatementJson,Integer userId,String userName,String orgName,HttpServletRequest request) {
    	ObjectMapper mapper = new ObjectMapper();
    	Map<String, Object> returnMap = new HashMap<String, Object>();
        StorageProfitlossStatement storageProfitlossStatement;
		try {
			storageProfitlossStatement = (StorageProfitlossStatement)mapper.readValue(profitlossStatementJson, StorageProfitlossStatement.class);
			returnMap = storageProfitlossStatementService.submit(storageProfitlossStatement,userId,userName,orgName);

		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

        return returnMap;
    }

    
}