package com.chinaitop.depot.profitlossStatement.service.impl;


import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.profitlossStatement.mapper.BusinessApprovalMapper;
import com.chinaitop.depot.profitlossStatement.mapper.StorageProfitlossStatementMapper;
import com.chinaitop.depot.profitlossStatement.model.BusinessApproval;
import com.chinaitop.depot.profitlossStatement.model.StorageProfitlossStatement;
import com.chinaitop.depot.profitlossStatement.model.StorageProfitlossStatementExample;
import com.chinaitop.depot.profitlossStatement.model.StorageProfitlossStatementExample.Criteria;
import com.chinaitop.depot.profitlossStatement.service.StorageProfitlossStatementService;
import com.chinaitop.depot.utils.AuditType;
import com.chinaitop.depot.utils.HistoryList;
import com.github.pagehelper.PageHelper;
import com.google.common.collect.Maps;


@Service
public class StorageProfitlossStatementServiceImpl implements StorageProfitlossStatementService {
	
	@Resource
	private StorageProfitlossStatementMapper storageProfitlossStatementMapper;
	
	@Resource
	private BusinessApprovalMapper businessApprovalMapper;

	@Override
	public List<StorageProfitlossStatement> queryByExample(Integer pageNum, Integer pageSize,
			StorageProfitlossStatement storageProfitlossStatement) {
		// TODO Auto-generated method stub

		StorageProfitlossStatementExample example = new StorageProfitlossStatementExample();
        Criteria createCriteria = example.createCriteria();
        
        // 仓房/油罐.
        if (StringUtils.isNotBlank(storageProfitlossStatement.getCforyg())){
            createCriteria.andCforygEqualTo(storageProfitlossStatement.getCforyg());
        }
        //货位
        if(storageProfitlossStatement.getHwid() != null){
        	createCriteria.andHwidEqualTo(storageProfitlossStatement.getHwid());
        }
        
        // 审批状态.
        if (storageProfitlossStatement.getAuditState() != null){
        	if(storageProfitlossStatement.getAuditState().equals(15)){//五级审批时的状态 全部为审批中
        		createCriteria.andAuditStateGreaterThanOrEqualTo(1);
        		createCriteria.andAuditStateLessThanOrEqualTo(5);
        	}else{
                createCriteria.andAuditStateEqualTo(storageProfitlossStatement.getAuditState());
        	}
        }
        
        if(storageProfitlossStatement.getOrgId() != null){
        	createCriteria.andOrgIdEqualTo(storageProfitlossStatement.getOrgId());
        }
        
        example.setOrderByClause("create_time desc");
      
        PageHelper.startPage(pageNum, pageSize);
        
        List<StorageProfitlossStatement> selectByExample = storageProfitlossStatementMapper.selectByExample(example);
        return selectByExample;
	}

	@Override
	public List<Map<String, Object>> jsRksfzzData(Map<String, Object> map) {
		// TODO Auto-generated method stub
		return storageProfitlossStatementMapper.jsRksfzzData(map);
	}

	@Override
	public List<Map<String, Object>> getCksl(Map<String, Object> map) {
		// TODO Auto-generated method stub
		return storageProfitlossStatementMapper.getCksl(map);
	}

	@Override
	public int add(StorageProfitlossStatement storageProfitlossStatement) {
		// TODO Auto-generated method stub
		return storageProfitlossStatementMapper.insertSelective(storageProfitlossStatement);
	}

	@Override
	public int update(StorageProfitlossStatement storageProfitlossStatement) {
		// TODO Auto-generated method stub
		return storageProfitlossStatementMapper.updateByPrimaryKeySelective(storageProfitlossStatement);
	}

	@Override
	public int remove(String id) {
		// TODO Auto-generated method stub
		return storageProfitlossStatementMapper.deleteByPrimaryKey(id);
	}

	@Override
	public StorageProfitlossStatement findById(String id) {
		// TODO Auto-generated method stub
		return storageProfitlossStatementMapper.selectByPrimaryKey(id);
	}

	@Override
	@Transactional(readOnly = false)
	public Map<String, Object> submit(StorageProfitlossStatement profitlossStatement,Integer userId,String userName,String orgName) {
		// TODO Auto-generated method stub
		
	        Map<String, Object> returnMap = new HashMap<String, Object>();
	        
	        
	        Integer auditState = profitlossStatement.getAuditState();
	        if (auditState!=null &&
	                 (!auditState.equals(AuditType.UNSUBMIT.getAuditCode()) && 
	                 !auditState.equals(AuditType.REJECT.getAuditCode()))) {
	            returnMap.put("success", "error");
	            returnMap.put("msg", "您已经提交该数据，无法再次提交！");
	            return returnMap;
	        }
	        
	        /**
	         * 审批信息数据
	         */
	        BusinessApproval businessApproval = new BusinessApproval();
			businessApproval.setOperateTime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));//操作时间
	        businessApproval.setOperator(userId+"");//已选择的审批人id
	        businessApproval.setOperatorName(userName);//已选择的审批人姓名
	        businessApproval.setCreateTime(new Date()); //创建时间
	        businessApproval.setFromDepartment(orgName); //部门 orgName
	    	businessApproval.setProjectName("损溢单审批");//名称
	        businessApproval.setTaskType("spill");//任务类型
	    	
	    	businessApproval.setApplyTime(profitlossStatement.getCreateTime());//申请时间
	        businessApproval.setTaskTypeName(profitlossStatement.getSydh());//任务类型名
	        businessApproval.setIsHide(0);//
	        businessApproval.setContent("同意");//审批意见
	        businessApproval.setTaskId(profitlossStatement.getId());
	        businessApproval.setTaskName("员工提交");//任务名称
	        
	        // 设置审批状态为，已经提交.等待第一级审批
	        profitlossStatement.setAuditState(AuditType.AUDIT1.getAuditCode());
	        // 修改.
	        int a = storageProfitlossStatementMapper.updateByPrimaryKeySelective(profitlossStatement);
	        if(a>0){
	        	 //增加审批表数据
	            int b = businessApprovalMapper.insertSelective(businessApproval);
	            if(b>0){
	            	returnMap.put("success", "success");
	            }else{
	            	returnMap.put("success", "error");
		            returnMap.put("msg", "提交失败！");
	            }
	        	
	        }else{
	        	returnMap.put("success", "error");
	            returnMap.put("msg", "提交失败！");
	        }
	        
	        return returnMap;
	    
	}

	@Override
	public List<Map<String, String>> getUserRole(Integer userId) {
		// TODO Auto-generated method stub
		return storageProfitlossStatementMapper.getUserRole(userId);
	}

	@Override
	public List<HistoryList> getAudit(Map<String, Object> modelMap) {
		// TODO Auto-generated method stub
		return businessApprovalMapper.getAudit(modelMap);
	}

	@Override
	public Map<String, Object> audit(StorageProfitlossStatement storageProfitlossStatement, Integer userId, String realName,
			String auditResult, String content,String orgName) {
		// TODO Auto-generated method stub
		Map<String, Object> modelMap = new HashMap<String, Object>();
        
		BusinessApproval businessApproval = new BusinessApproval();
		businessApproval.setOperateTime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));//操作时间
        businessApproval.setOperator(userId+"");//已选择的审批人id
        businessApproval.setOperatorName(realName);//已选择的审批人姓名
        businessApproval.setCreateTime(new Date()); //创建时间
        businessApproval.setFromDepartment(orgName); //部门 orgName
    	businessApproval.setProjectName("损溢单审批");//名称
        businessApproval.setTaskType("spill");//任务类型
    	
    	businessApproval.setApplyTime(storageProfitlossStatement.getCreateTime());//申请时间
        businessApproval.setTaskTypeName(storageProfitlossStatement.getSydh());//任务类型名
        businessApproval.setIsHide(0);//
        if(content != null && content != ""){
        	 businessApproval.setContent(content);//审批意见
        }else{
        	 businessApproval.setContent("同意");//审批意见
        }
       
        businessApproval.setTaskId(storageProfitlossStatement.getId());
        
        String result = "";
        //1通过2驳回3拒绝
        if ("1".equals(auditResult)) {
        	result = "同意";
        	
        	if(storageProfitlossStatement.getAuditState().equals(AuditType.AUDIT1.getAuditCode())){//仓储部审批
            	//更改该条数据
            	storageProfitlossStatement.setCcshr(userId);
            	storageProfitlossStatement.setAuditState(AuditType.AUDIT2.getAuditCode());
            	
            	//审批表数据的新增
                businessApproval.setTaskName(AuditType.AUDIT1.getAuditName());//任务名称

            }else{
            	
            	if(storageProfitlossStatement.getAuditState().equals(AuditType.AUDIT2.getAuditCode())){//质检审批
            		storageProfitlossStatement.setAuditState(AuditType.AUDIT3.getAuditCode());
            		storageProfitlossStatement.setZjshr(userId);
            		businessApproval.setTaskName(AuditType.AUDIT2.getAuditName());//任务名称
            		
            	}else if(storageProfitlossStatement.getAuditState().equals(AuditType.AUDIT3.getAuditCode())){//统计审批
            		storageProfitlossStatement.setAuditState(AuditType.AUDIT4.getAuditCode());
            		storageProfitlossStatement.setTjshr(userId);
            		businessApproval.setTaskName(AuditType.AUDIT3.getAuditName());//任务名称
            		
            	}else if(storageProfitlossStatement.getAuditState().equals(AuditType.AUDIT4.getAuditCode())){//会计审批
            		storageProfitlossStatement.setAuditState(AuditType.AUDIT5.getAuditCode());
            		storageProfitlossStatement.setKjshr(userId);
            		businessApproval.setTaskName(AuditType.AUDIT4.getAuditName());//任务名称
            	}else if(storageProfitlossStatement.getAuditState().equals(AuditType.AUDIT5.getAuditCode())){//库领导审批
            		storageProfitlossStatement.setAuditState(AuditType.AGREE.getAuditCode());//审批完毕
            		storageProfitlossStatement.setLdshr(userId);
            		businessApproval.setTaskName(AuditType.AUDIT5.getAuditName());//任务名称
            	}
            	
            }
        	
        } else if ("2".equals(auditResult) || "3".equals(auditResult)) {
        	

        	/**
        	 * 审批表的数据修改
        	 */
        	if(storageProfitlossStatement.getAuditState().equals(AuditType.AUDIT1.getAuditCode())){//仓储部审批
            	//审批表数据的新增
                businessApproval.setTaskName(AuditType.AUDIT1.getAuditName());//任务名称

            }else if(storageProfitlossStatement.getAuditState().equals(AuditType.AUDIT2.getAuditCode())){//质检审批
            	
        		businessApproval.setTaskName(AuditType.AUDIT2.getAuditName());//任务名称
        		
        	}else if(storageProfitlossStatement.getAuditState().equals(AuditType.AUDIT3.getAuditCode())){//统计审批
        		
        		businessApproval.setTaskName(AuditType.AUDIT3.getAuditName());//任务名称
        		
        	}else if(storageProfitlossStatement.getAuditState().equals(AuditType.AUDIT4.getAuditCode())){//会计审批
        		
        		businessApproval.setTaskName(AuditType.AUDIT4.getAuditName());//任务名称
        		
        	}else if(storageProfitlossStatement.getAuditState().equals(AuditType.AUDIT5.getAuditCode())){//库领导审批
        		
        		businessApproval.setTaskName(AuditType.AUDIT5.getAuditName());//任务名称
        	}
        	
        	if("2".equals(auditResult)){
        		
        		result = "驳回";
        		/**
            	 * 驳回到申请后驳回状态 可以重新提交
            	 * 主表之前的审批人不做变动 后面的提交审批 会覆盖之前的值
            	 */
            	storageProfitlossStatement.setAuditState(AuditType.REJECT.getAuditCode());
            	
        	}else if("3".equals(auditResult)){
        		result = "拒绝";
            	/**
            	 * 拒绝 则整条数据结束
            	 */
            	storageProfitlossStatement.setAuditState(AuditType.REFUSE.getAuditCode());
        	}
        } 
        
        businessApproval.setResult(result);//审批结果
        
       //修改本条数据
    	int  a = storageProfitlossStatementMapper.updateByPrimaryKeySelective(storageProfitlossStatement);
    	if(a>0){
    		 //增加审批表数据
            int b = businessApprovalMapper.insertSelective(businessApproval);
            if(b>0){
            	 modelMap.put("status", "success");
            }else{
            	 modelMap.put("status", "error");
            	 modelMap.put("msg", "流程数据新增不成功");
            }
    	}else{
    		modelMap.put("status", "error");
       	 modelMap.put("msg", "原数据修改不成功");
    	}
      
		return modelMap;
	}
	
	
}
